# Managed Service Identity
> see https://aka.ms/autorest

This is the AutoRest configuration file for Managed Service Identity.

---
## Getting Started
To build the SDK for Managed Service Identity, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration


### Basic Information
These are the global settings for the Managed Service Identity API.

``` yaml
openapi-type: arm
tag: package-2015-08-31-preview
```


### Tag: package-2015-08-31-preview

These settings apply only when `--tag=package-2015-08-31-preview` is specified on the command line.

``` yaml $(tag) == 'package-2015-08-31-preview'
input-file:
- Microsoft.ManagedIdentity/preview/2015-08-31-preview/ManagedIdentity.json
```

---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_msi']
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
```


## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.ManagedServiceIdentity
  output-folder: $(csharp-sdks-folder)/ManagedServiceIdentity/Management.ManagedServiceIdentity/Generated
  clear-output-folder: true
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.mgmt.msi
  package-name: azure-mgmt-msi
  clear-output-folder: true
```
``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-mgmt-msi/azure/mgmt/msi
```
``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-mgmt-msi
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.msi
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-msi
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2015-08-31-preview
```

### Tag: package-2015-08-31-preview and java

These settings apply only when `--tag=package-2015-08-31-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2015-08-31-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.managedserviceidentity.v2015_08_31_preview
  output-folder: $(azure-libraries-for-java-folder)/managedserviceidentity/resource-manager/v2015_08_31_preview
regenerate-manager: true
generate-interface: true
```


